/**
 * @author Aleksandr A. Lomov <lomov@cs.karelia.ru>
 * @date   02.03.2015
 * @brief  Base class for access point client.
 *
 * This file is part of the CuteSIB project.
 *
 * @section LICENSE
 *
 * CuteSIB is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * CuteSIB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CuteSIB; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * @section DESCRIPTION
 *
 * This class is used in the implementation of access point
 * to represent a client.
 *
 * Contact: http://oss.fruct.org/wiki/SmartSpace-platform
 * Copyright (C) 2015-2016 by PetrSU.
 */


#include "client.h"

#include <QtCore/QDebug>


#ifdef CUTESIB_DEBUG_INSTANCE_COUNTER
QAtomicInt cutesib::access_point::Client::instanceCounter = 0;
QAtomicInt cutesib::access_point::Client::maxInstanceCounter = 0;
#endif

/*****************************************************************************/
/************************** Constructors/destructors *************************/

cutesib::access_point::Client::Client(QObject *parent) : QObject(parent)
{
#ifdef CUTESIB_DEBUG_INSTANCE_COUNTER
    instanceCounter.ref();
    if (instanceCounter> maxInstanceCounter) maxInstanceCounter = instanceCounter;
    qDebug() << "Clients:" << instanceCounter << maxInstanceCounter;
#endif
}


cutesib::access_point::Client::~Client()
{
#ifdef CUTESIB_DEBUG_INSTANCE_COUNTER
    instanceCounter.deref();
    qDebug() << "Clients:" << instanceCounter << maxInstanceCounter;
#endif
}


/*****************************************************************************/
/****************************** Public methods *******************************/

QString cutesib::access_point::Client::nodeId()
{
    return nodeId_;
}


void cutesib::access_point::Client::setNodeId(QString nodeId)
{
    nodeId_ = nodeId;
}
