/**
* @author Ivan V. Galov <galov@cs.karelia.ru>
* @date   18.04.2016
* @brief  Handler for processing basic smart space operations.
*
* This file is part of the CuteSIB project.
*
* @section LICENSE
*
* CuteSIB is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* CuteSIB is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with CuteSIB; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA  02110-1301  USA
*
* @section DESCRIPTION
*
* Handles basic operations of SSAP protocol: query, insert, remove, update.
*
* Web-site: http://oss.fruct.org/wiki/SmartSpace-platform
* Copyright (C) 2015-2016 by PetrSU.
**/

#ifndef BASICOPERATIONHANDLER_H
#define BASICOPERATIONHANDLER_H

#include <redland.h>
#include <rasqal.h>
#include "triple.h"
#include "triplestore.h"
#include "command.h"
#include "commandresponse.h"
#include "operationhandler.h"
#include "siberrors.h"

#define wildcard1 	"sib:any"
#define wildcard2 	"http://www.nokia.com/NRC/M3/sib#any"

#define BASICOPERATIONHANDLER_ID "OH-BASIC-TRIPLES"

namespace cutesib {

class BasicOperationHandler : public OperationHandler
{
    Q_OBJECT

public:
    BasicOperationHandler(QObject *parent = 0);

    SibError initialize(Context *context);

    CommandResponse* insert(CommandRequest *command);
    CommandResponse* query(CommandRequest *command);
    CommandResponse* remove(CommandRequest *command);
    CommandResponse* update(CommandRequest *command);

    CommandResponse* perform(CommandRequest *command);

    Triple* statementToTriple(librdf_statement* statement);

signals:
   // void storeUpdated(CommandRequest *command);
    void queryResult(CommandResponse* commandResponse);

public slots:
    void updateState(CommandRequest *command);

private:
    void rdfInsert(QList<Triple*> insertTriples);
    QList<Triple*> rdfRemove(QList<Triple*> removeTriples);

    Triplestore* triplestore_;
    librdf_world* RDF_world;
    librdf_model* RDF_model;
};

}

#endif // BASICOPERATIONHANDLER_H
