/**
 * @author Aleksandr A. Lomov <lomov@cs.karelia.ru>
 * @date   25.09.2015
 * @brief  Response for processed command.
 *
 * This file is part of the CuteSIB project.
 *
 * @section LICENSE
 *
 * CuteSIB is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * CuteSIB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CuteSIB; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * @section DESCRIPTION
 *
 * When a module has processed a command (CommandRequest) it should send a response (when needed).
 * Response is sent when for CommandRequest 'needConfirmation' field has a true value.
 *
 * Web-site: http://oss.fruct.org/wiki/SmartSpace-platform
 * Copyright (C) 2015-2016 by PetrSU.
 */


#include "commandresponse.h"


/*****************************************************************************/
/************************** Constructors/destructors *************************/

cutesib::CommandResponse::CommandResponse(CommandRequest *request, bool isSuccesful, QObject *parent) :
    Command(request->Type(), request->To(), request->From(), parent = 0)
{
   request_ = request;
   isSuccessful_ = isSuccesful;

   if (isSuccessful_ == true) {
       errorCode_ = SibError::NONE;
   } else {
       errorCode_ = SibError::FALED;
   }
}


cutesib::CommandResponse::CommandResponse(cutesib::CommandRequest *request, cutesib::SibError error, QObject *parent) :
    Command(request->Type(), request->To(), request->From(), parent = 0)
{
    request_ = request;
    isSuccessful_ = (error == SibError::NONE) ? true : false;
}


cutesib::CommandResponse::~CommandResponse()
{
    foreach (Triple *t, triples_) {
        delete t;
    }

    delete request_;
}


/*****************************************************************************/
/****************************** Public methods *******************************/

void cutesib::CommandResponse::setTriples(QList<cutesib::Triple *> triples)
{
    triples_ = triples;
}


const QList<cutesib::Triple *> cutesib::CommandResponse::triples() const
{
    return triples_;
}
