/**
 * @author Aleksandr A. Lomov <lomov@cs.karelia.ru>
 * @date   29.04.2016
 * @brief  Contains runtime context for the SIB.
 *
 * This file is part of the CuteSIB project.
 *
 * @section LICENSE
 *
 * CuteSIB is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * CuteSIB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CuteSIB; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * @section DESCRIPTION
 *
 * SIB context contains configuration of the SIB, and provides access
 * to core SIB modules (#Scheduler, #Triplestore) and to additional modules (#SibModule).
 *
 * Web-site: http://oss.fruct.org/wiki/SmartSpace-platform
 * Copyright (C) 2016 by PetrSU.
 */


#include "context.h"
#include "sibmodule.h"
#include "command.h"


/*****************************************************************************/
/************************** Constructors/destructors *************************/

cutesib::Context::Context(QObject *parent) :  QObject(parent)
{

}


cutesib::Context::~Context()
{

}


/*****************************************************************************/
/****************************** Public methods *******************************/

cutesib::SibModule *cutesib::Context::getModule(QString id)
{
    QList<SibModule*>::Iterator it = std::find_if(
                modules_.begin(), modules_.end(),
                [id] (SibModule *m) {return m->id() == id;});

    return (it == modules_.end()) ? nullptr : *it;
}


cutesib::SibModule *cutesib::Context::getModule(CommandType type)
{
    return getModule(config_->getModuleId(type));
}
