/**
 * @author Aleksandr A. Lomov <lomov@cs.karelia.ru>
 * @date   01.02.2016
 * @brief  Base class for operations handler.
 *
 * This file is part of the CuteSIB project.
 *
 * @section LICENSE
 *
 * CuteSIB is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * CuteSIB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CuteSIB; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * @section DESCRIPTION
 *
 * OperationHandler is base class for operations handlers. Handlers implement logic to perform
 * actions with triples and triplestore.
 *
 * There are
 * - 4 basic operation: 'insert', 'remove', 'update', 'query';
 * - 1 basic persistent operation: subscription.
 * All operation works with triples, but each operation (paramteres) can be implemented with different ways.
 * For example 'update' could be done with row triples, with SPARQL UPDATE or with RDF/XML.
 * For basic subscription operation triples-patters are used, but it can be extended with SPARQL SELECT.
 *
 * Each handler has an identificator. This identificator is mapped with some command type (operation).
 * Based on this mapping Scheduler manages commands with operations to send it to the appropriate handler.
 * In this way SIB supports extensibility to perform new operations by including new handlers.
 *
 * Contact: http://oss.fruct.org/wiki/SmartSpace-platform
 * Copyright 2016 (C) by PetrSU.
 */


#include "operationhandler.h"


/*****************************************************************************/
/************************** Constructors/destructors *************************/

cutesib::OperationHandler::OperationHandler(QString id, bool needUpdatNotifications, QObject *parent)
    : SibModule(id, parent), needUpdateNotifications_(needUpdatNotifications)
{

}


cutesib::OperationHandler::~OperationHandler()
{
    needUpdateNotifications_ = false;
}


/*****************************************************************************/
/****************************** Public methods *******************************/

bool cutesib::OperationHandler::needUpdateNotifications()
{
    return needUpdateNotifications_;
}
