/**
 * @author Aleksandr A. Lomov <lomov@cs.karelia.ru>
 * @date   29.04.2016
 * @brief  Base class for SIB modules.
 *
 * This file is part of the CuteSIB project.
 *
 * @section LICENSE
 *
 * CuteSIB is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * CuteSIB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CuteSIB; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * @section DESCRIPTION
 *
 * SIB uses modules to implement functionality.
 * Each module have identifier and special method to perform commands (#CommandRequest).
 * Idetifier is associated with one or several command types.
 * #Scheduler based on association between module (id) and command (command type) forward
 * command to module for performing the command.
 * #CommandRequest contains information to perform operation (name. parameters etc.) and
 * module makes action to processing command and sends response (#CommandResponse).
 *
 * Web-site: http://oss.fruct.org/wiki/SmartSpace-platform
 * Copyright (C) 2016 by PetrSU.
 */


#include "sibmodule.h"
#include "context.h"


/*****************************************************************************/
/************************** Constructors/destructors *************************/

cutesib::SibModule::SibModule(QString id, QObject *parent) : QObject(parent), id_(id)
{

}


cutesib::SibModule::~SibModule()
{

}


/*****************************************************************************/
/****************************** Public methods *******************************/

cutesib::SibError cutesib::SibModule::initialize(cutesib::Context* context)
{
    context_ = context;
    return SibError::NONE;
}

