/**
 * @author Aleksandr A. Lomov <lomov@cs.karelia.ru>
 * @date   13.04.2015
 * @brief  Constants for parsing/creating SSAP messages.
 *
 * This file is part of the CuteSIB project.
 *
 * @section LICENSE
 *
 * CuteSIB is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * CuteSIB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CuteSIB; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * @section DESCRIPTION
 *
 * This class is used as a container of constants to parse/create SSAP/XML messages.
 *
 * Contact: http://oss.fruct.org/wiki/SmartSpace-platform
 * Copyright (C) 2015-2016 by PetrSU.
 */


#ifndef CUTESIB_SSAPCONSTANTS_H
#define CUTESIB_SSAPCONSTANTS_H


#include <QString>


namespace cutesib {

/**
 * @brief The SsapConstants class contans constants to parse/create SSAP/XML messages.
 */
class SsapConstants
{
public:
    /**
     * @brief SsapConstants class destructor.
     */
    ~SsapConstants();

    // SSAP request/response.
    static const QString MessageTypeRequest;
    static const QString MessageTypeResponse;

    // SSAP transactions/messages.
    static const QString TransactionTypeJoin;
    static const QString TransactionTypeLeave;
    static const QString TransactionTypeInsert;
    static const QString TransactionTypeUpdate;
    static const QString TransactionTypeRemove;
    static const QString TransactionTypeQuery;
    static const QString TransactionTypeSubscribe;
    static const QString TransactionTypeUnsubscribe;

    // Tags.
    static const QString TagParameter;

    // Tags for triples.
    static const QString TagTripleList;
    static const QString TagTriple;
    static const QString TagSubject;
    static const QString TagPredicate;
    static const QString TagObject;

    static const QString AttributeName;
    static const QString AttributeEncoding;
    static const QString AttributeType;

    static const QString AttributeValueRdfM3;

    // SSAP attributes values.
    static const QString AttributeValueInsertGraph;
    static const QString AttributeValueRemoveGraph;
    static const QString AttributeValueQueryGraph;
    static const QString AttributeValueConfirm;
    static const QString AttributeValueSubscriptionId;
    static const QString AttributeValueType;

    // SSAP parameters value. Tags <parameter ...>{value}</parameter>
    static const QString ParameterValueSparql;

    // SSAP attributes values for RDF types
    static const QString AttributeValueRdfTypeUri;
    static const QString AttributeValueRdfTypeLiteral;


private:
    /**
     * @brief SsapConstants class constructor is private to prevent creation of instances.
     */
    SsapConstants();
};

}

#endif // CUTESIB_SSAPCONSTANTS_H
