/**
* @author Ivan V. Galov <galov@cs.karelia.ru>
* @date   18.04.2016
* @brief  Handler for processing subscription operation.
*
* This file is part of the CuteSIB project.
*
* @section LICENSE
*
* CuteSIB is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* CuteSIB is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with CuteSIB; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA  02110-1301  USA
*
* @section DESCRIPTION
*
* Handles subscription operation of SSAP protocol.
*
* Web-site: http://oss.fruct.org/wiki/SmartSpace-platform
* Copyright (C) 2015-2016 by PetrSU.
**/

#ifndef SUBSCRIPTIONHANDLER_H
#define SUBSCRIPTIONHANDLER_H

#include "operationhandler.h"
#include "triplestore.h"
#include "commandresponse.h"
#include "subscription.h"
#include "context.h"
#include "siberrors.h"


#define SUBSCRIPTIONHANDLER_ID "OH-SUBSCRIPTION-TRIPLES"

namespace cutesib {

class SubscriptionHandler : public OperationHandler
{
    Q_OBJECT

public:
    SubscriptionHandler(QObject *parent = 0);

    SibError initialize(Context *context);

    CommandResponse* subscribe(CommandRequest *command);
    CommandResponse* unsubscribe(CommandRequest *command);

    void createSubscription(QString subscriptionId, QList<Triple *> queryList, QList<Triple*> initialTriples);

    CommandResponse* perform(CommandRequest* command);

public slots:
    void updateState(CommandRequest *command);

private:
    Triplestore* triplestore_;
    librdf_world* RDF_world;
    librdf_model* RDF_model;

    QList<Subscription*> subscriptionsList;
};

}

#endif // SUBSCRIPTIONHANDLER_H
