/**
 * @author Aleksandr A. Lomov <lomov@cs.karelia.ru>
 * @date   24.05.2016
 * @brief  Loader for discovery access point.
 *
 * This file is part of the CuteSIB project.
 *
 * @section LICENSE
 *
 * CuteSIB is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * CuteSIB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CuteSIB; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA  02110-1301  USA
 *
 * @section DESCRIPTION
 *
 * Loader for tcp access points.
 * Loader is a factory to create access point instances.
 * Also loader contains information about access points (version, protocol etc.).
 *
 * Web-site: http://oss.fruct.org/wiki/SmartSpace-platform
 * Copyright (C) 2015-2016 by PetrSU.
 */


#include "tcpaccesspointloader.h"

#include <QtCore/QtPlugin>
#include <QtCore/QMetaType>

#include "tcpaccesspoint.h"


/*****************************************************************************/
/*************************** Definitions/Constants ***************************/

#if QT_VERSION < 0x050000
    Q_EXPORT_PLUGIN2(TcpAccessPointLoader, cutesib::access_point::TcpAccessPointLoader)
#endif

const QString cutesib::access_point::TcpAccessPointLoader::id_(CUTESIB_TCPAP_SSAPXML_ID);
const QString cutesib::access_point::TcpAccessPointLoader::version_(CUTESIB_TCPAP_SSAPXML_VERSION);
const QString cutesib::access_point::TcpAccessPointLoader::description_(CUTESIB_TCPAP_SSAPXML_DESCRITION);
const QString cutesib::access_point::TcpAccessPointLoader::protocols_(CUTESIB_TCPAP_SSAPXML_PROTOCOLS);


/*****************************************************************************/
/************************** Constructors/destructors *************************/

cutesib::access_point::TcpAccessPointLoader::TcpAccessPointLoader()
{

}


/*****************************************************************************/
/****************************** Public methods *******************************/

QString cutesib::access_point::TcpAccessPointLoader::id()
{
    return id_;
}


QString cutesib::access_point::TcpAccessPointLoader::description()
{
    return description_;
}


QString cutesib::access_point::TcpAccessPointLoader::protocols()
{
    return protocols_;
}


QString cutesib::access_point::TcpAccessPointLoader::version()
{
    return version_;
}


cutesib::access_point::AccessPointInterface* cutesib::access_point::TcpAccessPointLoader::create(QString accessPointId, QString parameters)
{
    TcpAccessPoint *accessPoint = new TcpAccessPoint(this);
    accessPoint->initialize(accessPointId, parameters);
    return accessPoint;
}
